@@ -9,11 +9,11 @@ App::Ack - A container for functions for the ack program
 
 =head1 VERSION
 
-Version 1.25_01
+Version 1.25_02
 
 =cut
 
-our $VERSION = '1.25_01';
+our $VERSION = '1.25_02';
 
 =head1 SYNOPSIS
 
@@ -38,7 +38,10 @@ sub is_filetype {
     return;
 }
 
-our %ignore_dirs = map { ($_,1) } qw( CVS RCS .svn _darcs blib );
+our @ignore_dirs = qw( blib CVS RCS SCCS .svn _darcs );
+our %ignore_dirs = map { ($_,1) } @ignore_dirs;
+sub _ignore_dirs_str { return _listify( @ignore_dirs ); }
+
 
 =head2 skipdir_filter
 
@@ -54,9 +57,10 @@ sub skipdir_filter {
 
 our %types;
 our %mappings = (
+    asm         => [qw( s S )],
     cc          => [qw( c h )],
     css         => [qw( css )],
-    javascript  => [qw( js )],
+    js          => [qw( js )],
     parrot      => [qw( pir pasm pmc ops pod pg tg )],
     perl        => [qw( pl pm pod tt ttml t )],
     php         => [qw( php phpt htm html )],
@@ -144,6 +148,7 @@ sub show_help {
 
     for ( @lines ) {
         s/(\w+)(\s+)LIST/$1.$2._expand_list($1)/esmx;
+        s/IGNORE_DIRS/_ignore_dirs_str()/esmx;
     }
     print @lines;
 
@@ -154,9 +159,19 @@ sub _expand_list {
     my $lang = shift;
 
     my @files = map { ".$_" } @{$mappings{$lang}};
-    my $and = pop @files;
 
-    return @files ? join( ', ', @files ) . " and $and" : $and;
+    return _listify( @files );
+}
+
+sub _listify {
+    my @whats = @_;
+
+    return '' if !@whats;
+
+    return $whats[0] if @whats == 1;
+
+    my $end = pop @whats;
+    return join( ', ', @whats ) . " and $end";
 }
 
 =head1 AUTHOR
@@ -225,46 +240,49 @@ Default switches may be specified in ACK_SWITCHES environment variable.
 Example: ack -i select
 
 Searching:
-    -i                ignore case distinctions
-    -v                invert match: select non-matching lines
-    -w                force PATTERN to match only whole words
+    -i              ignore case distinctions
+    -v              invert match: select non-matching lines
+    -w              force PATTERN to match only whole words
 
 Search output:
-    -l                only print filenames containing matches
-    -o                show only the part of a line matching PATTERN
-    -m=NUM            stop after NUM matches
-    -H                print the filename for each match
-    -h                suppress the prefixing filename on output
-    -c, --count       show number of lines matching per file
-    --[no]group       print a blank line between each file's matches
-                      (default: on unless output is redirected)
-    --[no]color       highlight the matching text (default: on unless
-                      output is redirected, or on Windows)
+    -l              only print filenames containing matches
+    -o              show only the part of a line matching PATTERN
+                    (turns off text highlighting)
+    -o=expr         output the evaluation of expr for each line
+                    (turns off text highlighting)
+    -m=NUM          stop after NUM matches
+    -H              print the filename for each match
+    -h              suppress the prefixing filename on output
+    -c, --count     show number of lines matching per file
+    --[no]group     print a blank line between each file's matches
+                    (default: on unless output is redirected)
+    --[no]color     highlight the matching text (default: on unless
+                    output is redirected, or on Windows)
 
 File finding:
-    -f                only print the files found, without searching.
-                      The PATTERN must not be specified.
+    -f              only print the files found, without searching.
+                    The PATTERN must not be specified.
 
 File inclusion/exclusion:
-    -n                No descending into subdirectories
-    -a, --all         All files, regardless of extension
-                      (but still skips RCS, CVS, .svn, _darcs and blib dirs)
-    --[no]cc          LIST
-    --[no]javascript  LIST
-    --[no]js          same as --[no]javascript
-    --[no]parrot      LIST
-    --[no]perl        LIST
-    --[no]php         LIST
-    --[no]python      LIST
-    --[no]ruby        LIST
-    --[no]shell       LIST
-    --[no]sql         LIST
-    --[no]yaml        LIST
+    -n              No descending into subdirectories
+    -a, --all       All files, regardless of extension (but still skips
+                    IGNORE_DIRS dirs)
+    --[no]asm       LIST
+    --[no]cc        LIST
+    --[no]js        LIST
+    --[no]parrot    LIST
+    --[no]perl      LIST
+    --[no]php       LIST
+    --[no]python    LIST
+    --[no]ruby      LIST
+    --[no]shell     LIST
+    --[no]sql       LIST
+    --[no]yaml      LIST
 
 Miscellaneous:
-    --help            this help
-    --version         display version
-    --thpppt          Bill the Cat
+    --help          this help
+    --version       display version
+    --thpppt        Bill the Cat
 
 
 GOTCHAS:
